==> mit-scheme-9.0.tar.gz: mit-scheme-9.0/src/edwin/ed-ffi.scm <==
#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010 Massachusetts Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

(declare (usual-integrations))

;; This list must be kept in alphabetical order by filename.

(standard-scheme-find-file-initialization
 '#(("abbrev"	(edwin))
    ("ansi"	(edwin screen console-screen))
    ("argred"	(edwin command-argument))
    ("artdebug"	(edwin debugger))
    ("autold"	(edwin))
    ("autosv"	(edwin))
    ("basic"	(edwin))
    ("bios"	(edwin screen console-screen))
    ("bufcom"	(edwin))
    ("buffer"	(edwin))
    ("buffrm"	(edwin window))
    ("bufinp"	(edwin buffer-input-port))
    ("bufmnu"	(edwin buffer-menu))
    ("bufout"	(edwin buffer-output-port))
    ("bufset"	(edwin))
    ("bufwfs"	(edwin window))
    ("bufwin"	(edwin window))
    ("bufwiu"	(edwin window))
    ("bufwmc"	(edwin window))
    ("c-mode"	(edwin))
    ("calias"	(edwin))
    ("cinden"	(edwin c-indentation))
    ("class"	(edwin))
    ("clscon"	(edwin class-constructor))
    ("clsmac"	(edwin class-macros))
    ("comhst"	(edwin))
    ("comint"	(edwin))
    ("comatch"	(edwin))
    ("comman"	(edwin))
    ("compile"	(edwin))
    ("comred"	(edwin command-reader))
    ("comtab"	(edwin comtab))
    ("comwin"	(edwin window combination))
    ("curren"	(edwin))
    ("dabbrev"	(edwin))
    ("debian-changelog" (edwin debian-changelog))
    ("debug"	(edwin debugger))
    ("debuge"	(edwin))
    ("diff"	(edwin diff))
    ("dired"	(edwin dired))
    ("diros2"	(edwin dired))
    ("dirunx"	(edwin dired))
    ("dirw32"	(edwin dired))
    ("display"	(edwin display-type))
    ("docstr"	(edwin))
    ("dos"	(edwin))
    ("doscom"	(edwin dosjob))
    ("dosfile"	(edwin))
    ("dosproc"	(edwin process))
    ("dosshell"	(edwin dosjob))
    ("editor"	(edwin))
    ("edtfrm"	(edwin window))
    ("edtstr"	(edwin))
    ("evlcom"	(edwin))
    ("eystep"	(edwin stepper))
    ("filcom"	(edwin))
    ("fileio"	(edwin))
    ("fill"	(edwin))
    ("grpops"	(edwin group-operations))
    ("hlpcom"	(edwin))
    ("htmlmode"	(edwin))
    ("image"	(edwin))
    ("info"	(edwin info))
    ("input"	(edwin keyboard))
    ("intmod"	(edwin inferior-repl))
    ("iserch"	(edwin incremental-search))
    ("javamode"	(edwin))
    ("key-w32"	(edwin win32-keys))
    ("key-x11"	(edwin x-keys))
    ("keymap"	(edwin command-summary))
    ("keyparse"	(edwin keyparser))
    ("kilcom"	(edwin))
    ("kmacro"	(edwin))
    ("lincom"	(edwin))
    ("linden"	(edwin lisp-indentation))
    ("lisppaste" (edwin lisppaste))
    ("loadef"	(edwin))
    ("lspcom"	(edwin))
    ("macros"	(edwin macros))
    ("make"	())
    ("malias"	(edwin mail-alias))
    ("manual"	(edwin))
    ("midas"	(edwin))
    ("modefs"	(edwin))
    ("modes"	(edwin))
    ("modlin"	(edwin modeline-string))
    ("modwin"	(edwin window))
    ("motcom"	(edwin))
    ("motion"	(edwin))
    ("mousecom"	(edwin))
    ("nntp"	(edwin nntp))
    ("notify"	(edwin))
    ("nvector"	(edwin))
    ("occur"	(edwin occurrence))
    ("os2"	(edwin))
    ("os2com"	(edwin os2-commands))
    ("os2term"	(edwin screen os2-screen))
    ("outline"	(edwin))
    ("paredit"	(edwin paredit))
    ("pasmod"	(edwin))
    ("paths"	(edwin))
    ("print"	(edwin))
    ("process"	(edwin process))
    ("prompt"	(edwin prompt))
    ("pwedit"	(edwin password-edit))
    ("pwparse"	(edwin password-edit))
    ("rcsparse"	(edwin rcs-parse))
    ("reccom"	(edwin rectangle))
    ("regcom"	(edwin register-command))
    ("regexp"	(edwin regular-expression))
    ("regops"	(edwin))
    ("rename"	())
    ("replaz"	(edwin))
    ("rfc822"	(edwin rfc822))
    ("ring"	(edwin))
    ("rmail"	(edwin rmail))
    ("rmailsrt"	(edwin rmail))
    ("rmailsum"	(edwin rmail))
    ("schmod"	(edwin))
    ("scrcom"	(edwin))
    ("screen"	(edwin screen))
    ("search"	(edwin))
    ("sendmail"	(edwin sendmail))
    ("sercom"	(edwin))
    ("shell"	(edwin))
    ("simple"	(edwin))
    ("snr"	(edwin news-reader))
    ("sort"	(edwin))
    ("strpad"	(edwin))
    ("strtab"	(edwin))
    ("struct"	(edwin))
    ("syntax"	(edwin))
    ("tagutl"	(edwin tags))
    ("techinfo"	(edwin))
    ("telnet"	(edwin))
    ("termcap"	(edwin screen console-screen))
    ("texcom"	(edwin))
    ("things"	(edwin))
    ("tparse"	(edwin))
    ("tterm"	(edwin screen console-screen))
    ("tximod"	(edwin))
    ("txtprp"	(edwin text-properties))
    ("undo"	(edwin undo))
    ("unix"	(edwin))
    ("utils"	(edwin))
    ("utlwin"	(edwin window))
    ("vc"	(edwin vc))
    ("vc-bzr"	(edwin vc))
    ("vc-cvs"	(edwin vc))
    ("vc-git"	(edwin vc))
    ("vc-rcs"	(edwin vc))
    ("vc-svn"	(edwin vc))
    ("verilog"	(edwin verilog))
    ("vhdl"	(edwin vhdl))
    ("webster"	(edwin))
    ("win32"	(edwin screen win32))
    ("win32com"	(edwin win-commands))
    ("wincom"	(edwin))
    ("window"	(edwin window))
    ("winout"	(edwin window-output-port))
    ("winren"	(edwin))
    ("xcom"	(edwin x-commands))
    ("xform"	(edwin class-macros transform-instance-variables))
    ("xmodef"	(edwin))
    ("xterm"	(edwin screen x-screen))))

==> mit-scheme_9.1.1.orig.tar.gz: mit-scheme-9.1.1/src/edwin/ed-ffi.scm <==
#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011 Massachusetts Institute of
    Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

(declare (usual-integrations))

;; This list must be kept in alphabetical order by filename.

(standard-scheme-find-file-initialization
 '#(("abbrev"	(edwin))
    ("ansi"	(edwin screen console-screen))
    ("argred"	(edwin command-argument))
    ("artdebug"	(edwin debugger))
    ("autold"	(edwin))
    ("autosv"	(edwin))
    ("basic"	(edwin))
    ("bios"	(edwin screen console-screen))
    ("bufcom"	(edwin))
    ("buffer"	(edwin))
    ("buffrm"	(edwin window))
    ("bufinp"	(edwin buffer-input-port))
    ("bufmnu"	(edwin buffer-menu))
    ("bufout"	(edwin buffer-output-port))
    ("bufset"	(edwin))
    ("bufwfs"	(edwin window))
    ("bufwin"	(edwin window))
    ("bufwiu"	(edwin window))
    ("bufwmc"	(edwin window))
    ("c-mode"	(edwin))
    ("calias"	(edwin))
    ("cinden"	(edwin c-indentation))
    ("class"	(edwin))
    ("clscon"	(edwin class-constructor))
    ("clsmac"	(edwin class-macros))
    ("comhst"	(edwin))
    ("comint"	(edwin))
    ("comatch"	(edwin))
    ("comman"	(edwin))
    ("compile"	(edwin))
    ("comred"	(edwin command-reader))
    ("comtab"	(edwin comtab))
    ("comwin"	(edwin window combination))
    ("curren"	(edwin))
    ("dabbrev"	(edwin))
    ("debian-changelog" (edwin debian-changelog))
    ("debug"	(edwin debugger))
    ("debuge"	(edwin))
    ("diff"	(edwin diff))
    ("dired"	(edwin dired))
    ("diros2"	(edwin dired))
    ("dirunx"	(edwin dired))
    ("dirw32"	(edwin dired))
    ("display"	(edwin display-type))
    ("docstr"	(edwin))
    ("dos"	(edwin))
    ("doscom"	(edwin dosjob))
    ("dosfile"	(edwin))
    ("dosproc"	(edwin process))
    ("dosshell"	(edwin dosjob))
    ("editor"	(edwin))
    ("edtfrm"	(edwin window))
    ("edtstr"	(edwin))
    ("evlcom"	(edwin))
    ("eystep"	(edwin stepper))
    ("filcom"	(edwin))
    ("fileio"	(edwin))
    ("fill"	(edwin))
    ("grpops"	(edwin group-operations))
    ("hlpcom"	(edwin))
    ("htmlmode"	(edwin))
    ("image"	(edwin))
    ("info"	(edwin info))
    ("input"	(edwin keyboard))
    ("intmod"	(edwin inferior-repl))
    ("iserch"	(edwin incremental-search))
    ("javamode"	(edwin))
    ("key-w32"	(edwin win32-keys))
    ("key-x11"	(edwin x-keys))
    ("keymap"	(edwin command-summary))
    ("keyparse"	(edwin keyparser))
    ("kilcom"	(edwin))
    ("kmacro"	(edwin))
    ("lincom"	(edwin))
    ("linden"	(edwin lisp-indentation))
    ("lisppaste" (edwin lisppaste))
    ("loadef"	(edwin))
    ("lspcom"	(edwin))
    ("macros"	(edwin macros))
    ("make"	())
    ("malias"	(edwin mail-alias))
    ("manual"	(edwin))
    ("midas"	(edwin))
    ("modefs"	(edwin))
    ("modes"	(edwin))
    ("modlin"	(edwin modeline-string))
    ("modwin"	(edwin window))
    ("motcom"	(edwin))
    ("motion"	(edwin))
    ("mousecom"	(edwin))
    ("nntp"	(edwin nntp))
    ("notify"	(edwin))
    ("nvector"	(edwin))
    ("occur"	(edwin occurrence))
    ("os2"	(edwin))
    ("os2com"	(edwin os2-commands))
    ("os2term"	(edwin screen os2-screen))
    ("outline"	(edwin))
    ("paredit"	(edwin paredit))
    ("pasmod"	(edwin))
    ("paths"	(edwin))
    ("print"	(edwin))
    ("process"	(edwin process))
    ("prompt"	(edwin prompt))
    ("pwedit"	(edwin password-edit))
    ("pwparse"	(edwin password-edit))
    ("rcsparse"	(edwin rcs-parse))
    ("reccom"	(edwin rectangle))
    ("regcom"	(edwin register-command))
    ("regexp"	(edwin regular-expression))
    ("regops"	(edwin))
    ("rename"	())
    ("replaz"	(edwin))
    ("rfc822"	(edwin rfc822))
    ("ring"	(edwin))
    ("rmail"	(edwin rmail))
    ("rmailsrt"	(edwin rmail))
    ("rmailsum"	(edwin rmail))
    ("schmod"	(edwin))
    ("scrcom"	(edwin))
    ("screen"	(edwin screen))
    ("search"	(edwin))
    ("sendmail"	(edwin sendmail))
    ("sercom"	(edwin))
    ("shell"	(edwin))
    ("simple"	(edwin))
    ("snr"	(edwin news-reader))
    ("sort"	(edwin))
    ("strpad"	(edwin))
    ("strtab"	(edwin))
    ("struct"	(edwin))
    ("syntax"	(edwin))
    ("tagutl"	(edwin tags))
    ("techinfo"	(edwin))
    ("telnet"	(edwin))
    ("termcap"	(edwin screen console-screen))
    ("texcom"	(edwin))
    ("things"	(edwin))
    ("tparse"	(edwin))
    ("tterm"	(edwin screen console-screen))
    ("tximod"	(edwin))
    ("txtprp"	(edwin text-properties))
    ("undo"	(edwin undo))
    ("unix"	(edwin))
    ("utils"	(edwin))
    ("utlwin"	(edwin window))
    ("vc"	(edwin vc))
    ("vc-bzr"	(edwin vc))
    ("vc-cvs"	(edwin vc))
    ("vc-git"	(edwin vc))
    ("vc-rcs"	(edwin vc))
    ("vc-svn"	(edwin vc))
    ("verilog"	(edwin verilog))
    ("vhdl"	(edwin vhdl))
    ("webster"	(edwin))
    ("win32"	(edwin screen win32))
    ("win32com"	(edwin win-commands))
    ("wincom"	(edwin))
    ("window"	(edwin window))
    ("winout"	(edwin window-output-port))
    ("winren"	(edwin))
    ("xcom"	(edwin x-commands))
    ("xform"	(edwin class-macros transform-instance-variables))
    ("xmodef"	(edwin))
    ("xterm"	(edwin screen x-screen))))
